@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2024, by Samuel Williams.
+# Copyright, 2022-2025, by Samuel Williams.
 
 require_relative "body"
 require_relative "constants"
@@ -45,17 +45,12 @@ module Protocol
 				unless ignored.empty?
 					Console.warn(self, "Ignoring hop headers!", ignored: ignored)
 				end
-
+				
 				if hijack_body = meta["rack.hijack"]
 					body = hijack_body
 				end
-
-				body = Body.wrap(env, status, headers, body, request&.body)
-
-				if request&.head?
-					# I thought about doing this in Output.wrap, but decided the semantics are too tricky. Specifically, the various ways a rack response body can be wrapped, and the need to invoke #close at the right point.
-					body = ::Protocol::HTTP::Body::Head.for(body)
-				end
+				
+				body = Body.wrap(env, status, headers, body, request&.body, request&.head?)
 				
 				protocol = meta[RACK_PROTOCOL]
 				
